# klldFN
Use This To Upload Files To klldFN

[![Downloads](https://pepy.tech/badge/klldFN)](https://pepy.tech/project/klldv5)
[![Downloads](https://pepy.tech/badge/klldFN/week)](https://pepy.tech/project/klldFN)
[![Downloads](https://pepy.tech/badge/klldFN/month)](https://pepy.tech/project/klldFN)
[![Requires: Python 3.x](https://img.shields.io/pypi/pyversions/klldPinger.svg)](https://pypi.org/project/klldFN/)
[![Version: 1.0.1](https://img.shields.io/pypi/v/klldv5.svg)](https://pypi.org/project/klldFN/)

### Setup:
``pip install klldFN``

``pip3 install klldFN``

[Examples](https://github.com/klldme/klldFN/tree/main "github.com/klldme/klldv5/tree/main")

